@@ -15,7 +15,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/afs_util.c,v 1.5.4.2 2002/08/21 20:53:22 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/afs_util.c,v 1.5.4.3 2002/11/14 21:03:57 zacheiss Exp $");
 
 #include "../afs/stds.h"
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
@@ -71,6 +71,16 @@ char *afs_cv2string(char *ttp, afs_uint32 aval)
 
 } /*afs_cv2string*/
 
+char *afs_strchr(char *s, int c)
+{
+    char *p;
+   
+    for (p = s; *p; p++)
+      if (*p == c)
+	return p;
+    return NULL;
+}
+
 void print_internet_address(char *preamble, struct srvAddr *sa,
 			    char *postamble, int flag)
 {
